﻿// Copyright (c) Strange Loop Games. All rights reserved.
// See LICENSE file in the project root for full license information.

//Mod created by ORG Development
//Feel free to make changes to the mod for use in your own Eco server, or redistribute a modification of the mod for use in Eco games. Please note that Strange Loop Games reserves the rights to all modified Eco Content

namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using Eco.Gameplay.Items;
    using Eco.World.Blocks;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Core.Utils;
    using Eco.Shared.Serialization;
    using Eco.Shared.Localization;
    using Eco.Core.Items;
    using Eco.World;
    using Eco.World.Blocks;

    [Serialized, Weight(28000)]
    [LocDisplayName("Concentrated Wet Tailings")]
    [MaxStackSize(10)]
    [RequiresTool(typeof(ShovelItem))]
    [Tag("Excavatable", 1)]
    [Ecopedia("Blocks", "Byproducts", true, InPageTooltip.DynamicTooltip)]
    public class ConcentratedWetTailingsItem : BlockItem<ConcentratedWetTailingsBlock>
    {
        public override LocString DisplayNamePlural { get { return Localizer.DoStr("Concentrated Wet Tailings"); } }
        public override LocString DisplayDescription { get { return Localizer.DoStr("Three wet tailings blocks compressed into one. The run-off creates five times the ground pollution of a wet tailings block; killing nearby plants and seeping into the water supply."); } }
        public override bool CanStickToWalls { get { return false; } }
    }

    //Change "SmeltingSkill" below to "AdvancedSmeltingSkill", if you want it to only be crafted by advanced smelters. The number "4" is the required skill level to unlock the recipe, and can be changed as well
    //If you change the required skill, be sure to find and replace all instances of "SmeltingSkill" in this file with the skill you have replaced it with
    [RequiresSkill(typeof(SmeltingSkill), 4)]
    public partial class ConcentratedWetTailingsRecipe :
        RecipeFamily
    {
        public ConcentratedWetTailingsRecipe()
        {
            this.Recipes = new List<Recipe>
            {
                new Recipe(
                    "ConcentratedWetTailings",
                    Localizer.DoStr("Concentrated Wet Tailings"),
                    new IngredientElement[]
                    {
                    new IngredientElement(typeof(WetTailingsItem), 3, true)//The "3" here sets the amount of Tailings required at 3. This number can be modified to allow more or less tailings required to craft a concentrated tailing
                    },
                    new CraftingElement[]
                    {
                    new CraftingElement<ConcentratedWetTailingsItem>(1),

                    }
                )
            };
            this.LaborInCalories = CreateLaborInCaloriesValue(250, typeof(SmeltingSkill)); //Change 250 to the amount of calories you want the crafting to consume
            this.ExperienceOnCraft = .25f; //Change .25f to the amount of experience you want crafting to give. Note that fractional numbers (1.5, 0.8, 5.75) must be followed by an "f" (1.5f, 0.8f, 5.75f)
            this.CraftMinutes = CreateCraftTimeValue(typeof(ConcentratedWetTailingsRecipe), 2f, typeof(SmeltingSkill), typeof(SmeltingFocusedSpeedTalent), typeof(SmeltingParallelSpeedTalent)); //Replace 2 with the time required to craft here (in minutes)
            this.ModsPreInitialize();
            this.Initialize(Localizer.DoStr("Concentrated Wet Tailings"), typeof(ConcentratedWetTailingsRecipe));
            this.ModsPostInitialize();

            CraftingComponent.AddRecipe(typeof(BlastFurnaceObject), this); //Change "BlastFurnaceObject" with the crafting table you want this to be crafted in
        }

        /// <summary>Hook for mods to customize RecipeFamily before initialization. You can change recipes, xp, labor, time here.</summary>
        partial void ModsPreInitialize();
        /// <summary>Hook for mods to customize RecipeFamily after initialization, but before registration. You can change skill requirements here.</summary>
        partial void ModsPostInitialize();
    }
}